# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CampaignExperimentErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignExperimentError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CampaignExperimentErrorEnum.CampaignExperimentError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CampaignExperimentErrorEnum.CampaignExperimentError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CampaignExperimentErrorEnum.CampaignExperimentError]]: ...
        UNSPECIFIED = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 0)
        UNKNOWN = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 1)
        DUPLICATE_NAME = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 2)
        INVALID_TRANSITION = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 3)
        CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 4)
        CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 5)
        CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 6)
        CUSTOMER_CANNOT_CREATE_EXPERIMENT = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 7)
        CAMPAIGN_CANNOT_CREATE_EXPERIMENT = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 8)
        EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 9)
        EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 10)
        CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 11)
    UNSPECIFIED = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 0)
    UNKNOWN = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 1)
    DUPLICATE_NAME = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 2)
    INVALID_TRANSITION = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 3)
    CANNOT_CREATE_EXPERIMENT_WITH_SHARED_BUDGET = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 4)
    CANNOT_CREATE_EXPERIMENT_FOR_REMOVED_BASE_CAMPAIGN = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 5)
    CANNOT_CREATE_EXPERIMENT_FOR_NON_PROPOSED_DRAFT = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 6)
    CUSTOMER_CANNOT_CREATE_EXPERIMENT = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 7)
    CAMPAIGN_CANNOT_CREATE_EXPERIMENT = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 8)
    EXPERIMENT_DURATIONS_MUST_NOT_OVERLAP = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 9)
    EXPERIMENT_DURATION_MUST_BE_WITHIN_CAMPAIGN_DURATION = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 10)
    CANNOT_MUTATE_EXPERIMENT_DUE_TO_STATUS = typing___cast(CampaignExperimentErrorEnum.CampaignExperimentError, 11)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignExperimentErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v2.services.transports.ad_group_audience_view_service_grpc_transport import AdGroupAudienceViewServiceGrpcTransport
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar
from google.ads.google_ads.v2.proto.resources.ad_group_audience_view_pb2 import AdGroupAudienceView

class AdGroupAudienceViewServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> AdGroupAudienceViewServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> AdGroupAudienceViewServiceClient: ...
    @classmethod
    def ad_group_audience_view_path(cls, customer: Any, ad_group_audience_view: Any) -> str: ...
    transport: Union[AdGroupAudienceViewServiceGrpcTransport, Callable[[Credentials, type], AdGroupAudienceViewServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[AdGroupAudienceViewServiceGrpcTransport, Callable[[Credentials, type], AdGroupAudienceViewServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def get_ad_group_audience_view(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> AdGroupAudienceView: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CustomInterestErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CustomInterestError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CustomInterestErrorEnum.CustomInterestError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CustomInterestErrorEnum.CustomInterestError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CustomInterestErrorEnum.CustomInterestError]]: ...
        UNSPECIFIED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 0)
        UNKNOWN = typing___cast(CustomInterestErrorEnum.CustomInterestError, 1)
        NAME_ALREADY_USED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 2)
        CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 3)
        TYPE_AND_PARAMETER_NOT_FOUND = typing___cast(CustomInterestErrorEnum.CustomInterestError, 4)
        TYPE_AND_PARAMETER_ALREADY_EXISTED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 5)
        INVALID_CUSTOM_INTEREST_MEMBER_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 6)
        CANNOT_REMOVE_WHILE_IN_USE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 7)
        CANNOT_CHANGE_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 8)
    UNSPECIFIED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 0)
    UNKNOWN = typing___cast(CustomInterestErrorEnum.CustomInterestError, 1)
    NAME_ALREADY_USED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 2)
    CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 3)
    TYPE_AND_PARAMETER_NOT_FOUND = typing___cast(CustomInterestErrorEnum.CustomInterestError, 4)
    TYPE_AND_PARAMETER_ALREADY_EXISTED = typing___cast(CustomInterestErrorEnum.CustomInterestError, 5)
    INVALID_CUSTOM_INTEREST_MEMBER_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 6)
    CANNOT_REMOVE_WHILE_IN_USE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 7)
    CANNOT_CHANGE_TYPE = typing___cast(CustomInterestErrorEnum.CustomInterestError, 8)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomInterestErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class AdGroupTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class AdGroupType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> AdGroupTypeEnum.AdGroupType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[AdGroupTypeEnum.AdGroupType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, AdGroupTypeEnum.AdGroupType]]: ...
        UNSPECIFIED = typing___cast(AdGroupTypeEnum.AdGroupType, 0)
        UNKNOWN = typing___cast(AdGroupTypeEnum.AdGroupType, 1)
        SEARCH_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupType, 2)
        DISPLAY_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupType, 3)
        SHOPPING_PRODUCT_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 4)
        HOTEL_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 6)
        SHOPPING_SMART_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 7)
        VIDEO_BUMPER = typing___cast(AdGroupTypeEnum.AdGroupType, 8)
        VIDEO_TRUE_VIEW_IN_STREAM = typing___cast(AdGroupTypeEnum.AdGroupType, 9)
        VIDEO_TRUE_VIEW_IN_DISPLAY = typing___cast(AdGroupTypeEnum.AdGroupType, 10)
        VIDEO_NON_SKIPPABLE_IN_STREAM = typing___cast(AdGroupTypeEnum.AdGroupType, 11)
        VIDEO_OUTSTREAM = typing___cast(AdGroupTypeEnum.AdGroupType, 12)
        SEARCH_DYNAMIC_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 13)
        SHOPPING_COMPARISON_LISTING_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 14)
    UNSPECIFIED = typing___cast(AdGroupTypeEnum.AdGroupType, 0)
    UNKNOWN = typing___cast(AdGroupTypeEnum.AdGroupType, 1)
    SEARCH_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupType, 2)
    DISPLAY_STANDARD = typing___cast(AdGroupTypeEnum.AdGroupType, 3)
    SHOPPING_PRODUCT_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 4)
    HOTEL_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 6)
    SHOPPING_SMART_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 7)
    VIDEO_BUMPER = typing___cast(AdGroupTypeEnum.AdGroupType, 8)
    VIDEO_TRUE_VIEW_IN_STREAM = typing___cast(AdGroupTypeEnum.AdGroupType, 9)
    VIDEO_TRUE_VIEW_IN_DISPLAY = typing___cast(AdGroupTypeEnum.AdGroupType, 10)
    VIDEO_NON_SKIPPABLE_IN_STREAM = typing___cast(AdGroupTypeEnum.AdGroupType, 11)
    VIDEO_OUTSTREAM = typing___cast(AdGroupTypeEnum.AdGroupType, 12)
    SEARCH_DYNAMIC_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 13)
    SHOPPING_COMPARISON_LISTING_ADS = typing___cast(AdGroupTypeEnum.AdGroupType, 14)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class BiddingStrategyTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class BiddingStrategyType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> BiddingStrategyTypeEnum.BiddingStrategyType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[BiddingStrategyTypeEnum.BiddingStrategyType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, BiddingStrategyTypeEnum.BiddingStrategyType]]: ...
        UNSPECIFIED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 0)
        UNKNOWN = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 1)
        COMMISSION = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 16)
        ENHANCED_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 2)
        MANUAL_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 3)
        MANUAL_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 4)
        MANUAL_CPV = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 13)
        MAXIMIZE_CONVERSIONS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 10)
        MAXIMIZE_CONVERSION_VALUE = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 11)
        PAGE_ONE_PROMOTED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 5)
        PERCENT_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 12)
        TARGET_CPA = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 6)
        TARGET_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 14)
        TARGET_IMPRESSION_SHARE = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 15)
        TARGET_OUTRANK_SHARE = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 7)
        TARGET_ROAS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 8)
        TARGET_SPEND = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 9)
    UNSPECIFIED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 0)
    UNKNOWN = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 1)
    COMMISSION = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 16)
    ENHANCED_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 2)
    MANUAL_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 3)
    MANUAL_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 4)
    MANUAL_CPV = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 13)
    MAXIMIZE_CONVERSIONS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 10)
    MAXIMIZE_CONVERSION_VALUE = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 11)
    PAGE_ONE_PROMOTED = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 5)
    PERCENT_CPC = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 12)
    TARGET_CPA = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 6)
    TARGET_CPM = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 14)
    TARGET_IMPRESSION_SHARE = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 15)
    TARGET_OUTRANK_SHARE = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 7)
    TARGET_ROAS = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 8)
    TARGET_SPEND = typing___cast(BiddingStrategyTypeEnum.BiddingStrategyType, 9)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BiddingStrategyTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.billing_setup_status_pb2 import (
    BillingSetupStatusEnum as google___ads___googleads___v2___enums___billing_setup_status_pb2___BillingSetupStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.time_type_pb2 import (
    TimeTypeEnum as google___ads___googleads___v2___enums___time_type_pb2___TimeTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class BillingSetup(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PaymentsAccountInfo(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def payments_account_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def payments_account_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def payments_profile_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def payments_profile_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def secondary_payments_profile_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        def __init__(self,
            *,
            payments_account_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            payments_account_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            payments_profile_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            payments_profile_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            secondary_payments_profile_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> BillingSetup.PaymentsAccountInfo: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"payments_account_id",u"payments_account_name",u"payments_profile_id",u"payments_profile_name",u"secondary_payments_profile_id"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"payments_account_id",u"payments_account_name",u"payments_profile_id",u"payments_profile_name",u"secondary_payments_profile_id"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"payments_account_id",b"payments_account_id",u"payments_account_name",b"payments_account_name",u"payments_profile_id",b"payments_profile_id",u"payments_profile_name",b"payments_profile_name",u"secondary_payments_profile_id",b"secondary_payments_profile_id"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"payments_account_id",b"payments_account_id",u"payments_account_name",b"payments_account_name",u"payments_profile_id",b"payments_profile_id",u"payments_profile_name",b"payments_profile_name",u"secondary_payments_profile_id",b"secondary_payments_profile_id"]) -> None: ...

    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v2___enums___billing_setup_status_pb2___BillingSetupStatusEnum.BillingSetupStatus
    start_time_type = ... # type: google___ads___googleads___v2___enums___time_type_pb2___TimeTypeEnum.TimeType
    end_time_type = ... # type: google___ads___googleads___v2___enums___time_type_pb2___TimeTypeEnum.TimeType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def payments_account(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def payments_account_info(self) -> BillingSetup.PaymentsAccountInfo: ...

    @property
    def start_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def end_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___billing_setup_status_pb2___BillingSetupStatusEnum.BillingSetupStatus] = None,
        payments_account : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        payments_account_info : typing___Optional[BillingSetup.PaymentsAccountInfo] = None,
        start_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        start_time_type : typing___Optional[google___ads___googleads___v2___enums___time_type_pb2___TimeTypeEnum.TimeType] = None,
        end_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        end_time_type : typing___Optional[google___ads___googleads___v2___enums___time_type_pb2___TimeTypeEnum.TimeType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BillingSetup: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"end_date_time",u"end_time",u"end_time_type",u"id",u"payments_account",u"payments_account_info",u"start_date_time",u"start_time",u"start_time_type"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"end_date_time",u"end_time",u"end_time_type",u"id",u"payments_account",u"payments_account_info",u"resource_name",u"start_date_time",u"start_time",u"start_time_type",u"status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"end_date_time",b"end_date_time",u"end_time",b"end_time",u"end_time_type",b"end_time_type",u"id",b"id",u"payments_account",b"payments_account",u"payments_account_info",b"payments_account_info",u"start_date_time",b"start_date_time",u"start_time",b"start_time",u"start_time_type",b"start_time_type"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"end_date_time",b"end_date_time",u"end_time",b"end_time",u"end_time_type",b"end_time_type",u"id",b"id",u"payments_account",b"payments_account",u"payments_account_info",b"payments_account_info",u"resource_name",b"resource_name",u"start_date_time",b"start_date_time",u"start_time",b"start_time",u"start_time_type",b"start_time_type",u"status",b"status"]) -> None: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"end_time",b"end_time"]) -> typing_extensions___Literal["end_date_time","end_time_type"]: ...
    @typing___overload
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"start_time",b"start_time"]) -> typing_extensions___Literal["start_date_time","start_time_type"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ClickTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ClickType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ClickTypeEnum.ClickType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ClickTypeEnum.ClickType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ClickTypeEnum.ClickType]]: ...
        UNSPECIFIED = typing___cast(ClickTypeEnum.ClickType, 0)
        UNKNOWN = typing___cast(ClickTypeEnum.ClickType, 1)
        APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickType, 2)
        BREADCRUMBS = typing___cast(ClickTypeEnum.ClickType, 3)
        BROADBAND_PLAN = typing___cast(ClickTypeEnum.ClickType, 4)
        CALL_TRACKING = typing___cast(ClickTypeEnum.ClickType, 5)
        CALLS = typing___cast(ClickTypeEnum.ClickType, 6)
        CLICK_ON_ENGAGEMENT_AD = typing___cast(ClickTypeEnum.ClickType, 7)
        GET_DIRECTIONS = typing___cast(ClickTypeEnum.ClickType, 8)
        LOCATION_EXPANSION = typing___cast(ClickTypeEnum.ClickType, 9)
        LOCATION_FORMAT_CALL = typing___cast(ClickTypeEnum.ClickType, 10)
        LOCATION_FORMAT_DIRECTIONS = typing___cast(ClickTypeEnum.ClickType, 11)
        LOCATION_FORMAT_IMAGE = typing___cast(ClickTypeEnum.ClickType, 12)
        LOCATION_FORMAT_LANDING_PAGE = typing___cast(ClickTypeEnum.ClickType, 13)
        LOCATION_FORMAT_MAP = typing___cast(ClickTypeEnum.ClickType, 14)
        LOCATION_FORMAT_STORE_INFO = typing___cast(ClickTypeEnum.ClickType, 15)
        LOCATION_FORMAT_TEXT = typing___cast(ClickTypeEnum.ClickType, 16)
        MOBILE_CALL_TRACKING = typing___cast(ClickTypeEnum.ClickType, 17)
        OFFER_PRINTS = typing___cast(ClickTypeEnum.ClickType, 18)
        OTHER = typing___cast(ClickTypeEnum.ClickType, 19)
        PRODUCT_EXTENSION_CLICKS = typing___cast(ClickTypeEnum.ClickType, 20)
        PRODUCT_LISTING_AD_CLICKS = typing___cast(ClickTypeEnum.ClickType, 21)
        SITELINKS = typing___cast(ClickTypeEnum.ClickType, 22)
        STORE_LOCATOR = typing___cast(ClickTypeEnum.ClickType, 23)
        URL_CLICKS = typing___cast(ClickTypeEnum.ClickType, 25)
        VIDEO_APP_STORE_CLICKS = typing___cast(ClickTypeEnum.ClickType, 26)
        VIDEO_CALL_TO_ACTION_CLICKS = typing___cast(ClickTypeEnum.ClickType, 27)
        VIDEO_CARD_ACTION_HEADLINE_CLICKS = typing___cast(ClickTypeEnum.ClickType, 28)
        VIDEO_END_CAP_CLICKS = typing___cast(ClickTypeEnum.ClickType, 29)
        VIDEO_WEBSITE_CLICKS = typing___cast(ClickTypeEnum.ClickType, 30)
        VISUAL_SITELINKS = typing___cast(ClickTypeEnum.ClickType, 31)
        WIRELESS_PLAN = typing___cast(ClickTypeEnum.ClickType, 32)
        PRODUCT_LISTING_AD_LOCAL = typing___cast(ClickTypeEnum.ClickType, 33)
        PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = typing___cast(ClickTypeEnum.ClickType, 34)
        PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = typing___cast(ClickTypeEnum.ClickType, 35)
        PRODUCT_LISTING_ADS_COUPON = typing___cast(ClickTypeEnum.ClickType, 36)
        PRODUCT_LISTING_AD_TRANSACTABLE = typing___cast(ClickTypeEnum.ClickType, 37)
        PRODUCT_AD_APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickType, 38)
        SHOWCASE_AD_CATEGORY_LINK = typing___cast(ClickTypeEnum.ClickType, 39)
        SHOWCASE_AD_LOCAL_STOREFRONT_LINK = typing___cast(ClickTypeEnum.ClickType, 40)
        SHOWCASE_AD_ONLINE_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickType, 42)
        SHOWCASE_AD_LOCAL_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickType, 43)
        PROMOTION_EXTENSION = typing___cast(ClickTypeEnum.ClickType, 44)
        SWIPEABLE_GALLERY_AD_HEADLINE = typing___cast(ClickTypeEnum.ClickType, 45)
        SWIPEABLE_GALLERY_AD_SWIPES = typing___cast(ClickTypeEnum.ClickType, 46)
        SWIPEABLE_GALLERY_AD_SEE_MORE = typing___cast(ClickTypeEnum.ClickType, 47)
        SWIPEABLE_GALLERY_AD_SITELINK_ONE = typing___cast(ClickTypeEnum.ClickType, 48)
        SWIPEABLE_GALLERY_AD_SITELINK_TWO = typing___cast(ClickTypeEnum.ClickType, 49)
        SWIPEABLE_GALLERY_AD_SITELINK_THREE = typing___cast(ClickTypeEnum.ClickType, 50)
        SWIPEABLE_GALLERY_AD_SITELINK_FOUR = typing___cast(ClickTypeEnum.ClickType, 51)
        SWIPEABLE_GALLERY_AD_SITELINK_FIVE = typing___cast(ClickTypeEnum.ClickType, 52)
        HOTEL_PRICE = typing___cast(ClickTypeEnum.ClickType, 53)
        PRICE_EXTENSION = typing___cast(ClickTypeEnum.ClickType, 54)
        HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = typing___cast(ClickTypeEnum.ClickType, 55)
        SHOPPING_COMPARISON_LISTING = typing___cast(ClickTypeEnum.ClickType, 56)
    UNSPECIFIED = typing___cast(ClickTypeEnum.ClickType, 0)
    UNKNOWN = typing___cast(ClickTypeEnum.ClickType, 1)
    APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickType, 2)
    BREADCRUMBS = typing___cast(ClickTypeEnum.ClickType, 3)
    BROADBAND_PLAN = typing___cast(ClickTypeEnum.ClickType, 4)
    CALL_TRACKING = typing___cast(ClickTypeEnum.ClickType, 5)
    CALLS = typing___cast(ClickTypeEnum.ClickType, 6)
    CLICK_ON_ENGAGEMENT_AD = typing___cast(ClickTypeEnum.ClickType, 7)
    GET_DIRECTIONS = typing___cast(ClickTypeEnum.ClickType, 8)
    LOCATION_EXPANSION = typing___cast(ClickTypeEnum.ClickType, 9)
    LOCATION_FORMAT_CALL = typing___cast(ClickTypeEnum.ClickType, 10)
    LOCATION_FORMAT_DIRECTIONS = typing___cast(ClickTypeEnum.ClickType, 11)
    LOCATION_FORMAT_IMAGE = typing___cast(ClickTypeEnum.ClickType, 12)
    LOCATION_FORMAT_LANDING_PAGE = typing___cast(ClickTypeEnum.ClickType, 13)
    LOCATION_FORMAT_MAP = typing___cast(ClickTypeEnum.ClickType, 14)
    LOCATION_FORMAT_STORE_INFO = typing___cast(ClickTypeEnum.ClickType, 15)
    LOCATION_FORMAT_TEXT = typing___cast(ClickTypeEnum.ClickType, 16)
    MOBILE_CALL_TRACKING = typing___cast(ClickTypeEnum.ClickType, 17)
    OFFER_PRINTS = typing___cast(ClickTypeEnum.ClickType, 18)
    OTHER = typing___cast(ClickTypeEnum.ClickType, 19)
    PRODUCT_EXTENSION_CLICKS = typing___cast(ClickTypeEnum.ClickType, 20)
    PRODUCT_LISTING_AD_CLICKS = typing___cast(ClickTypeEnum.ClickType, 21)
    SITELINKS = typing___cast(ClickTypeEnum.ClickType, 22)
    STORE_LOCATOR = typing___cast(ClickTypeEnum.ClickType, 23)
    URL_CLICKS = typing___cast(ClickTypeEnum.ClickType, 25)
    VIDEO_APP_STORE_CLICKS = typing___cast(ClickTypeEnum.ClickType, 26)
    VIDEO_CALL_TO_ACTION_CLICKS = typing___cast(ClickTypeEnum.ClickType, 27)
    VIDEO_CARD_ACTION_HEADLINE_CLICKS = typing___cast(ClickTypeEnum.ClickType, 28)
    VIDEO_END_CAP_CLICKS = typing___cast(ClickTypeEnum.ClickType, 29)
    VIDEO_WEBSITE_CLICKS = typing___cast(ClickTypeEnum.ClickType, 30)
    VISUAL_SITELINKS = typing___cast(ClickTypeEnum.ClickType, 31)
    WIRELESS_PLAN = typing___cast(ClickTypeEnum.ClickType, 32)
    PRODUCT_LISTING_AD_LOCAL = typing___cast(ClickTypeEnum.ClickType, 33)
    PRODUCT_LISTING_AD_MULTICHANNEL_LOCAL = typing___cast(ClickTypeEnum.ClickType, 34)
    PRODUCT_LISTING_AD_MULTICHANNEL_ONLINE = typing___cast(ClickTypeEnum.ClickType, 35)
    PRODUCT_LISTING_ADS_COUPON = typing___cast(ClickTypeEnum.ClickType, 36)
    PRODUCT_LISTING_AD_TRANSACTABLE = typing___cast(ClickTypeEnum.ClickType, 37)
    PRODUCT_AD_APP_DEEPLINK = typing___cast(ClickTypeEnum.ClickType, 38)
    SHOWCASE_AD_CATEGORY_LINK = typing___cast(ClickTypeEnum.ClickType, 39)
    SHOWCASE_AD_LOCAL_STOREFRONT_LINK = typing___cast(ClickTypeEnum.ClickType, 40)
    SHOWCASE_AD_ONLINE_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickType, 42)
    SHOWCASE_AD_LOCAL_PRODUCT_LINK = typing___cast(ClickTypeEnum.ClickType, 43)
    PROMOTION_EXTENSION = typing___cast(ClickTypeEnum.ClickType, 44)
    SWIPEABLE_GALLERY_AD_HEADLINE = typing___cast(ClickTypeEnum.ClickType, 45)
    SWIPEABLE_GALLERY_AD_SWIPES = typing___cast(ClickTypeEnum.ClickType, 46)
    SWIPEABLE_GALLERY_AD_SEE_MORE = typing___cast(ClickTypeEnum.ClickType, 47)
    SWIPEABLE_GALLERY_AD_SITELINK_ONE = typing___cast(ClickTypeEnum.ClickType, 48)
    SWIPEABLE_GALLERY_AD_SITELINK_TWO = typing___cast(ClickTypeEnum.ClickType, 49)
    SWIPEABLE_GALLERY_AD_SITELINK_THREE = typing___cast(ClickTypeEnum.ClickType, 50)
    SWIPEABLE_GALLERY_AD_SITELINK_FOUR = typing___cast(ClickTypeEnum.ClickType, 51)
    SWIPEABLE_GALLERY_AD_SITELINK_FIVE = typing___cast(ClickTypeEnum.ClickType, 52)
    HOTEL_PRICE = typing___cast(ClickTypeEnum.ClickType, 53)
    PRICE_EXTENSION = typing___cast(ClickTypeEnum.ClickType, 54)
    HOTEL_BOOK_ON_GOOGLE_ROOM_SELECTION = typing___cast(ClickTypeEnum.ClickType, 55)
    SHOPPING_COMPARISON_LISTING = typing___cast(ClickTypeEnum.ClickType, 56)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ClickTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BytesValue as google___protobuf___wrappers_pb2___BytesValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class YoutubeVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def youtube_video_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        youtube_video_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> YoutubeVideoAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"youtube_video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"youtube_video_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"youtube_video_id",b"youtube_video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"youtube_video_id",b"youtube_video_id"]) -> None: ...

class MediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...

    def __init__(self,
        *,
        data : typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaBundleAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...

class ImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    mime_type = ... # type: google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum.MimeType

    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...

    @property
    def file_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def full_size(self) -> ImageDimension: ...

    def __init__(self,
        *,
        data : typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
        file_size : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        mime_type : typing___Optional[google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum.MimeType] = None,
        full_size : typing___Optional[ImageDimension] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ImageAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"data",u"file_size",u"full_size"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data",u"file_size",u"full_size",u"mime_type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"data",b"data",u"file_size",b"file_size",u"full_size",b"full_size"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data",u"file_size",b"file_size",u"full_size",b"full_size",u"mime_type",b"mime_type"]) -> None: ...

class ImageDimension(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def height_pixels(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def width_pixels(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        height_pixels : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        width_pixels : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ImageDimension: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"height_pixels",u"url",u"width_pixels"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"height_pixels",u"url",u"width_pixels"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"height_pixels",b"height_pixels",u"url",b"url",u"width_pixels",b"width_pixels"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"height_pixels",b"height_pixels",u"url",b"url",u"width_pixels",b"width_pixels"]) -> None: ...

class TextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TextAsset: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"text",b"text"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.criteria_pb2 import (
    AdScheduleInfo as google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo,
    KeywordInfo as google___ads___googleads___v1___common___criteria_pb2___KeywordInfo,
)

from google.ads.google_ads.v1.proto.enums.feed_item_target_device_pb2 import (
    FeedItemTargetDeviceEnum as google___ads___googleads___v1___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum,
)

from google.ads.google_ads.v1.proto.enums.feed_item_target_type_pb2 import (
    FeedItemTargetTypeEnum as google___ads___googleads___v1___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class FeedItemTarget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    feed_item_target_type = ... # type: google___ads___googleads___v1___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetType
    device = ... # type: google___ads___googleads___v1___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDevice

    @property
    def feed_item(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def feed_item_target_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def keyword(self) -> google___ads___googleads___v1___common___criteria_pb2___KeywordInfo: ...

    @property
    def geo_target_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad_schedule(self) -> google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        feed_item : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        feed_item_target_type : typing___Optional[google___ads___googleads___v1___enums___feed_item_target_type_pb2___FeedItemTargetTypeEnum.FeedItemTargetType] = None,
        feed_item_target_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        campaign : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        keyword : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___KeywordInfo] = None,
        geo_target_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        device : typing___Optional[google___ads___googleads___v1___enums___feed_item_target_device_pb2___FeedItemTargetDeviceEnum.FeedItemTargetDevice] = None,
        ad_schedule : typing___Optional[google___ads___googleads___v1___common___criteria_pb2___AdScheduleInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedItemTarget: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"ad_schedule",u"campaign",u"device",u"feed_item",u"feed_item_target_id",u"geo_target_constant",u"keyword",u"target"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"ad_schedule",u"campaign",u"device",u"feed_item",u"feed_item_target_id",u"feed_item_target_type",u"geo_target_constant",u"keyword",u"resource_name",u"target"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"ad_schedule",b"ad_schedule",u"campaign",b"campaign",u"device",b"device",u"feed_item",b"feed_item",u"feed_item_target_id",b"feed_item_target_id",u"geo_target_constant",b"geo_target_constant",u"keyword",b"keyword",u"target",b"target"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"ad_schedule",b"ad_schedule",u"campaign",b"campaign",u"device",b"device",u"feed_item",b"feed_item",u"feed_item_target_id",b"feed_item_target_id",u"feed_item_target_type",b"feed_item_target_type",u"geo_target_constant",b"geo_target_constant",u"keyword",b"keyword",u"resource_name",b"resource_name",u"target",b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"target",b"target"]) -> typing_extensions___Literal["campaign","ad_group","keyword","geo_target_constant","device","ad_schedule"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class LocalPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class LocalPlaceholderField(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> LocalPlaceholderFieldEnum.LocalPlaceholderField: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[LocalPlaceholderFieldEnum.LocalPlaceholderField]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, LocalPlaceholderFieldEnum.LocalPlaceholderField]]: ...
        UNSPECIFIED = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 0)
        UNKNOWN = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 1)
        DEAL_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 2)
        DEAL_NAME = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 3)
        SUBTITLE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 4)
        DESCRIPTION = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 5)
        PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 6)
        FORMATTED_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 7)
        SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 8)
        FORMATTED_SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 9)
        IMAGE_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 10)
        ADDRESS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 11)
        CATEGORY = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 12)
        CONTEXTUAL_KEYWORDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 13)
        FINAL_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 14)
        FINAL_MOBILE_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 15)
        TRACKING_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 16)
        ANDROID_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 17)
        SIMILAR_DEAL_IDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 18)
        IOS_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 19)
        IOS_APP_STORE_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 20)
    UNSPECIFIED = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 0)
    UNKNOWN = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 1)
    DEAL_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 2)
    DEAL_NAME = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 3)
    SUBTITLE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 4)
    DESCRIPTION = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 5)
    PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 6)
    FORMATTED_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 7)
    SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 8)
    FORMATTED_SALE_PRICE = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 9)
    IMAGE_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 10)
    ADDRESS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 11)
    CATEGORY = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 12)
    CONTEXTUAL_KEYWORDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 13)
    FINAL_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 14)
    FINAL_MOBILE_URLS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 15)
    TRACKING_URL = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 16)
    ANDROID_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 17)
    SIMILAR_DEAL_IDS = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 18)
    IOS_APP_LINK = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 19)
    IOS_APP_STORE_ID = typing___cast(LocalPlaceholderFieldEnum.LocalPlaceholderField, 20)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LocalPlaceholderFieldEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.simulation_pb2 import (
    CpcBidSimulationPointList as google___ads___googleads___v2___common___simulation_pb2___CpcBidSimulationPointList,
    CpvBidSimulationPointList as google___ads___googleads___v2___common___simulation_pb2___CpvBidSimulationPointList,
    TargetCpaSimulationPointList as google___ads___googleads___v2___common___simulation_pb2___TargetCpaSimulationPointList,
)

from google.ads.google_ads.v2.proto.enums.simulation_modification_method_pb2 import (
    SimulationModificationMethodEnum as google___ads___googleads___v2___enums___simulation_modification_method_pb2___SimulationModificationMethodEnum,
)

from google.ads.google_ads.v2.proto.enums.simulation_type_pb2 import (
    SimulationTypeEnum as google___ads___googleads___v2___enums___simulation_type_pb2___SimulationTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupSimulation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v2___enums___simulation_type_pb2___SimulationTypeEnum.SimulationType
    modification_method = ... # type: google___ads___googleads___v2___enums___simulation_modification_method_pb2___SimulationModificationMethodEnum.SimulationModificationMethod

    @property
    def ad_group_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def cpc_bid_point_list(self) -> google___ads___googleads___v2___common___simulation_pb2___CpcBidSimulationPointList: ...

    @property
    def cpv_bid_point_list(self) -> google___ads___googleads___v2___common___simulation_pb2___CpvBidSimulationPointList: ...

    @property
    def target_cpa_point_list(self) -> google___ads___googleads___v2___common___simulation_pb2___TargetCpaSimulationPointList: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ad_group_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___simulation_type_pb2___SimulationTypeEnum.SimulationType] = None,
        modification_method : typing___Optional[google___ads___googleads___v2___enums___simulation_modification_method_pb2___SimulationModificationMethodEnum.SimulationModificationMethod] = None,
        start_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        end_date : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        cpc_bid_point_list : typing___Optional[google___ads___googleads___v2___common___simulation_pb2___CpcBidSimulationPointList] = None,
        cpv_bid_point_list : typing___Optional[google___ads___googleads___v2___common___simulation_pb2___CpvBidSimulationPointList] = None,
        target_cpa_point_list : typing___Optional[google___ads___googleads___v2___common___simulation_pb2___TargetCpaSimulationPointList] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupSimulation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_id",u"cpc_bid_point_list",u"cpv_bid_point_list",u"end_date",u"point_list",u"start_date",u"target_cpa_point_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_id",u"cpc_bid_point_list",u"cpv_bid_point_list",u"end_date",u"modification_method",u"point_list",u"resource_name",u"start_date",u"target_cpa_point_list",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_group_id",b"ad_group_id",u"cpc_bid_point_list",b"cpc_bid_point_list",u"cpv_bid_point_list",b"cpv_bid_point_list",u"end_date",b"end_date",u"point_list",b"point_list",u"start_date",b"start_date",u"target_cpa_point_list",b"target_cpa_point_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_group_id",b"ad_group_id",u"cpc_bid_point_list",b"cpc_bid_point_list",u"cpv_bid_point_list",b"cpv_bid_point_list",u"end_date",b"end_date",u"modification_method",b"modification_method",u"point_list",b"point_list",u"resource_name",b"resource_name",u"start_date",b"start_date",u"target_cpa_point_list",b"target_cpa_point_list",u"type",b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"point_list",b"point_list"]) -> typing_extensions___Literal["cpc_bid_point_list","cpv_bid_point_list","target_cpa_point_list"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry,
)

from google.ads.google_ads.v2.proto.enums.ad_group_ad_status_pb2 import (
    AdGroupAdStatusEnum as google___ads___googleads___v2___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.ad_strength_pb2 import (
    AdStrengthEnum as google___ads___googleads___v2___enums___ad_strength_pb2___AdStrengthEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)

from google.ads.google_ads.v2.proto.resources.ad_pb2 import (
    Ad as google___ads___googleads___v2___resources___ad_pb2___Ad,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class AdGroupAd(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v2___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum.AdGroupAdStatus
    ad_strength = ... # type: google___ads___googleads___v2___enums___ad_strength_pb2___AdStrengthEnum.AdStrength

    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def ad(self) -> google___ads___googleads___v2___resources___ad_pb2___Ad: ...

    @property
    def policy_summary(self) -> AdGroupAdPolicySummary: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___ad_group_ad_status_pb2___AdGroupAdStatusEnum.AdGroupAdStatus] = None,
        ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad : typing___Optional[google___ads___googleads___v2___resources___ad_pb2___Ad] = None,
        policy_summary : typing___Optional[AdGroupAdPolicySummary] = None,
        ad_strength : typing___Optional[google___ads___googleads___v2___enums___ad_strength_pb2___AdStrengthEnum.AdStrength] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupAd: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad",u"ad_group",u"policy_summary"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad",u"ad_group",u"ad_strength",u"policy_summary",u"resource_name",u"status"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad",b"ad",u"ad_group",b"ad_group",u"policy_summary",b"policy_summary"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad",b"ad",u"ad_group",b"ad_group",u"ad_strength",b"ad_strength",u"policy_summary",b"policy_summary",u"resource_name",b"resource_name",u"status",b"status"]) -> None: ...

class AdGroupAdPolicySummary(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    review_status = ... # type: google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatus
    approval_status = ... # type: google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatus

    @property
    def policy_topic_entries(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry]: ...

    def __init__(self,
        *,
        policy_topic_entries : typing___Optional[typing___Iterable[google___ads___googleads___v2___common___policy_pb2___PolicyTopicEntry]] = None,
        review_status : typing___Optional[google___ads___googleads___v2___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatus] = None,
        approval_status : typing___Optional[google___ads___googleads___v2___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatus] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdGroupAdPolicySummary: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"approval_status",u"policy_topic_entries",u"review_status"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"approval_status",b"approval_status",u"policy_topic_entries",b"policy_topic_entries",u"review_status",b"review_status"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class RecommendationTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class RecommendationType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> RecommendationTypeEnum.RecommendationType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[RecommendationTypeEnum.RecommendationType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, RecommendationTypeEnum.RecommendationType]]: ...
        UNSPECIFIED = typing___cast(RecommendationTypeEnum.RecommendationType, 0)
        UNKNOWN = typing___cast(RecommendationTypeEnum.RecommendationType, 1)
        CAMPAIGN_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 2)
        KEYWORD = typing___cast(RecommendationTypeEnum.RecommendationType, 3)
        TEXT_AD = typing___cast(RecommendationTypeEnum.RecommendationType, 4)
        TARGET_CPA_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 5)
        MAXIMIZE_CONVERSIONS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 6)
        ENHANCED_CPC_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 7)
        SEARCH_PARTNERS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 8)
        MAXIMIZE_CLICKS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 9)
        OPTIMIZE_AD_ROTATION = typing___cast(RecommendationTypeEnum.RecommendationType, 10)
        CALLOUT_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 11)
        SITELINK_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 12)
        CALL_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 13)
        KEYWORD_MATCH_TYPE = typing___cast(RecommendationTypeEnum.RecommendationType, 14)
        MOVE_UNUSED_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 15)
    UNSPECIFIED = typing___cast(RecommendationTypeEnum.RecommendationType, 0)
    UNKNOWN = typing___cast(RecommendationTypeEnum.RecommendationType, 1)
    CAMPAIGN_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 2)
    KEYWORD = typing___cast(RecommendationTypeEnum.RecommendationType, 3)
    TEXT_AD = typing___cast(RecommendationTypeEnum.RecommendationType, 4)
    TARGET_CPA_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 5)
    MAXIMIZE_CONVERSIONS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 6)
    ENHANCED_CPC_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 7)
    SEARCH_PARTNERS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 8)
    MAXIMIZE_CLICKS_OPT_IN = typing___cast(RecommendationTypeEnum.RecommendationType, 9)
    OPTIMIZE_AD_ROTATION = typing___cast(RecommendationTypeEnum.RecommendationType, 10)
    CALLOUT_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 11)
    SITELINK_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 12)
    CALL_EXTENSION = typing___cast(RecommendationTypeEnum.RecommendationType, 13)
    KEYWORD_MATCH_TYPE = typing___cast(RecommendationTypeEnum.RecommendationType, 14)
    MOVE_UNUSED_BUDGET = typing___cast(RecommendationTypeEnum.RecommendationType, 15)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RecommendationTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
